Context

Struct Context 

pub struct Context { /* private fields */ }
The kmod context

let ctx = kmod::Context::new().unwrap();

Implementations

Source

impl Context

pub fn new() -> Result<Context>

Create a new kmod context.

let ctx = kmod::Context::new().unwrap();
pub fn new_with_dirname(dirname: &Path) -> Result<Context>

Create a new kmod context with given directory to search for kernel modules.

use std::path::Path;
let ctx = kmod::Context::new_with_dirname(&Path::new("/lib/modules/6.0.9")).unwrap();
pub fn modules_loaded(&self) -> Result<ModuleIterator>

Get an iterator of all loaded modules.

let ctx = kmod::Context::new().unwrap();
for module in ctx.modules_loaded().unwrap() {
    // ...
}
pub fn module_new_from_lookup<S: AsRef<OsStr>>( &self, alias: S, ) -> Result<ModuleIterator>

Create a module struct by looking up a name or alias.

use std::ffi::{OsStr, OsString};
let ctx = kmod::Context::new()?;
let module = ctx.module_new_from_lookup(&OsString::from("vfat"))?;
pub fn module_new_from_path<S: AsRef<OsStr>>( &self, filename: S, ) -> Result<Module>

Create a module struct by path.

let ctx = kmod::Context::new().unwrap();
let module = ctx.module_new_from_path("foo.ko");
pub fn module_new_from_name(&self, name: &str) -> Result<Module>

Create a module struct by name.

let ctx = kmod::Context::new().unwrap();
let module = ctx.module_new_from_name("tun").unwrap();
pub fn dirname(&self) -> OsString

Get the directory where kernel modules are stored

let ctx = kmod::Context::new().unwrap();
let dirname = ctx.dirname();